@@ -1,15 +1,13 @@
 package Perinci::Exporter;
 
-our $DATE = '2014-12-05'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 use experimental 'smartmatch';
 
-use Scalar::Util qw(reftype);
-
 # what a generic name, this hash caches the wrapped functions, so that when
 # importer asks to import a wrapped function with default wrapping options, we
 # don't have to call wrap_sub again. customly wrapped functions are not cached
@@ -52,7 +50,7 @@ sub install_import {
 
 sub do_export {
     my $expopts;
-    if ($_[0] && (reftype($_[0]) // '') eq 'HASH') {
+    if ($_[0] && ref($_[0]) eq 'HASH') {
         $expopts = shift;
     } else {
         die "First argument to do_export() must be export options";
@@ -115,7 +113,7 @@ sub do_export {
             next;
         } else {
             my $el = {};
-            if (@_ && (reftype($_[0]) // '') eq 'HASH') {
+            if (@_ && ref($_[0]) eq 'HASH') {
                 my $io = shift;
                 $el->{$_} = $io->{$_} for keys %$io;
             };
@@ -184,7 +182,7 @@ sub do_export {
             my $wrap;
             if (defined $imp->{wrap}) {
                 $wrap = $imp->{wrap};
-                if ((reftype($wrap) // '') eq 'HASH') {
+                if (ref($wrap) eq 'HASH') {
                     $use_default_wrap_args = 0;
                 }
             } else {
@@ -192,7 +190,7 @@ sub do_export {
             }
             if ($wrap) {
                 # copy
-                if ((reftype($wrap) // '') eq 'HASH') {
+                if (ref($wrap) eq 'HASH') {
                     $wrap = { %$wrap };
                     $use_default_wrap_args = keys(%$wrap) == 0;
                 } else {
@@ -271,7 +269,7 @@ Perinci::Exporter - Metadata-aware Exporter
 
 =head1 VERSION
 
-This document describes version 0.05 of Perinci::Exporter (from Perl distribution Perinci-Exporter), released on 2014-12-05.
+This document describes version 0.06 of Perinci::Exporter (from Perl distribution Perinci-Exporter), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
@@ -631,20 +629,6 @@ Note: L<Perinci::Sub::property::curry> is needed for this.
 
 They can still be exported if you list them in @EXPORT or @EXPORT_OK.
 
-=head1 TODO/IDEAS
-
-=over 4
-
-=item * Support combining tags?
-
- use YourModule qw(not(:tag1));
- use YourModule qw(and(:tag1,:tag2));
- use YourModule qw(or(:tag1,and(:tag2,:tag3)));
-
-=item * Export variables, etc.
-
-=back
-
 =head1 SEE ALSO
 
 L<Perinci>
@@ -673,7 +657,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
